# Energy Monitoring Tool (EMT)

Empowering Digital Sustainability Through Granular Energy Insights

## Key Capabilities:

- Real-time energy utilization with device-level breakdown.
- Attributes energy traces from each device to individual processes.
- Estimates each process's energy share based on proportional resource usage.
- Modular and extendable software architecture for future growth.
- Currently support Intel CPU(s) (RAPL) and Nvidia GPU(s) on Linux.
- Easy integration into Python applications using a Python context manager.
- Upcoming: A CLI tool to track energy usage of running applications (in any language) by tagging the uderlying processes.
- Integrated visualization interface for energy data using TensorBoard.

EMT quantifies the energy consumption of digital solutions, such as AI models and software applications, to guide sustainable development and operations.